#    This file is part of Recently Used Desklet
#
#    Recently Used Desklet is free software; you can redistribute it and/or
#    modify it under the terms of the GNU General Public License as
#    published by the Free Software Foundation; either version 2 of
#    the License, or (at your option) any later version.
 
#    Recently Used Desklet is distributed in the hope that it will be
#    useful, but WITHOUT ANY WARRANTY; without even the implied
#    warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#    See the GNU General Public License for more details.
 
#    You should have received a copy of the GNU General Public License
#    along with Recently Used Desklet; if not, write to the Free
#    Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
#    02111-1307  USA

import string
import md5
import os
import commands
import gconf

class MimeIcon:

    __DEFAULT_GCONF_THEME = "gnome"

    __DEFAULT_ICON_DIR =  os.path.join(
        commands.getoutput("dirname `which gnome-desktop-item-edit`"),
        "..", "share", "icons",
        __DEFAULT_GCONF_THEME,
        "48x48/mimetypes")
    
    # the unknown icon
    __UNKNOWN_ICON = "gnome-mime-application.png"

    def __init__(self, mime_type, theme = __DEFAULT_GCONF_THEME):

        self.__mime_type = mime_type
        self.__theme = theme
        # the pixmap directory of GNOME        
        self.__gnome_icon_dir =  os.path.join(
            commands.getoutput("dirname `which gnome-desktop-item-edit`"),
            "..", "share", "icons",
            theme,
            "48x48/mimetypes")
        self.__gnome_scalable_icon_dir =  os.path.join(
            commands.getoutput("dirname `which gnome-desktop-item-edit`"),
            "..", "share", "icons",
            theme,
            "scalable/mimetypes")        
        self.__path = ""

        self.__initialize()

    #
    # Initializes the icon path
    #
    def __initialize(self):
        self.__mime_type = self.__mime_type.replace("/","-")

        ### HACK  for the plain/text files
        if ( self.__mime_type == "gnome-mime-text-plain" ):
            self.__mime_type = "gnome-mime-text"
        ### HACK, hack hack; it's like i'm a chain smoker here :)
        if ( self.__mime_type == "text-plain" ):
            self.__mime_type = "text"

        png_file = "gnome-mime-" + self.__mime_type + ".png"
        svg_file = "gnome-mime-" + self.__mime_type + ".svg"        

        path = os.path.join(self.__gnome_icon_dir, png_file )
        scalable = os.path.join(self.__gnome_scalable_icon_dir, svg_file )

        if ( os.path.exists(scalable) ):
            self.__path = scalable
        elif ( not os.path.exists(path) ):
            self.__path = self.__get_unknown(png_file)
        else:
            self.__path = path

    #
    # Slight HACK, we need to get a default icon and if this
    #   theme doesn't provide we need to fall back on one that does
    #
    #   Algorithm:
    #       Check in current theme for default mime-icon
    #       Check in default theme for current mime-type
    #       If here, return default theme default mime-icon
    #
    def __get_unknown(self, mime_icon):
        c_theme = os.path.join(self.__gnome_icon_dir,
                               self.__UNKNOWN_ICON)
        if ( os.path.exists(c_theme) ):
            return c_theme
        d_theme = os.path.join(self.__DEFAULT_ICON_DIR,
                               mime_icon)
        if ( os.path.exists(d_theme) ):
            return d_theme
        
        return os.path.join(self.__DEFAULT_ICON_DIR,
                            self.__UNKNOWN_ICON)

    def get_path(self):
        return self.__path
